##########
User guide
##########

neophile can be installed directly from PyPI and run as a command-line tool, but it is normally run via GitHub Actions.

.. toctree::
   :caption: Guides

   prerequisites
   running
   github-actions
   managing-dependencies

.. toctree::
   :caption: Reference

   cli
